
.. image:: https://travis-ci.com/sdpython/mlstatpy.svg?branch=master
    :target: https://travis-ci.com/sdpython/mlstatpy
    :alt: Build status

.. image:: https://ci.appveyor.com/api/projects/status/5env33qptorgshaq?svg=true
    :target: https://ci.appveyor.com/project/sdpython/mlstatpy
    :alt: Build Status Windows

.. image:: https://circleci.com/gh/sdpython/mlstatpy/tree/master.svg?style=svg
    :target: https://circleci.com/gh/sdpython/mlstatpy/tree/master

.. image:: https://badge.fury.io/py/mlstatpy.svg
    :target: https://pypi.org/project/mlstatpy/

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :alt: MIT License
    :target: http://opensource.org/licenses/MIT

.. image:: https://requires.io/github/sdpython/mlstatpy/requirements.svg?branch=master
     :target: https://requires.io/github/sdpython/mlstatpy/requirements/?branch=master
     :alt: Requirements Status

.. image:: https://codecov.io/github/sdpython/mlstatpy/coverage.svg?branch=master
    :target: https://codecov.io/github/sdpython/mlstatpy?branch=master

.. image:: http://img.shields.io/github/issues/sdpython/mlstatpy.png
    :alt: GitHub Issues
    :target: https://github.com/sdpython/mlstatpy/issues

.. image:: https://api.codacy.com/project/badge/Grade/677db5dda93b40d4ba1ec2f870cfd934
    :target: https://www.codacy.com/app/sdpython/mlstatpy?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=sdpython/mlstatpy&amp;utm_campaign=Badge_Grade
    :alt: Codacy

.. image:: http://www.xavierdupre.fr/app/mlstatpy/helpsphinx/_images/nbcov.png
    :target: http://www.xavierdupre.fr/app/mlstatpy/helpsphinx/all_notebooks_coverage.html
    :alt: Notebook Coverage

.. _l-README:

mlstatpy
========

Le module contient essentiellement des digressions mathématiques
autour du machine learning. Parmi les choses intéressantes,
une courbe *ROC* avec intervalle de confiance, détection
automatique de segment dans une image, un algorithme
d'autocomplétion, une distance d'édition entre graphes,
des petites choses pour les données de Wikipedia,
un algorithme de conversion d'un arbre de décision en
réseaux de neurones.

The package mostly contains documentation. It also implements
some code rarely needed such as ROC curve with bandwidth,
automated segment detection in a image, some simple autocomplete
algorithm, a graph edit distance, some helpers on Wikipedia data,
an algorithm to convert decision trees into neural network.

* `GitHub/mlstatpy <https://github.com/sdpython/mlstatpy/>`_
* `documentation <http://www.xavierdupre.fr/app/mlstatpy/helpsphinx/index.html>`_
* `Blog <http://www.xavierdupre.fr/app/mlstatpy/helpsphinx/blog/main_0000.html#ap-main-0>`_
